
/* Generated data (by glib-mkenums) */


/* --- bstmarker.h --- */
  { "BstMarkerType", G_TYPE_ENUM, &bst__type_id__BstMarkerType, bst_marker_type_values },

/* --- bstmenus.h --- */
  { "BstChoiceFlags", G_TYPE_FLAGS, &bst__type_id__BstChoiceFlags, bst_choice_flags_values },

/* --- bstqsampler.h --- */
  { "BstQSamplerType", G_TYPE_FLAGS, &bst__type_id__BstQSamplerType, bst_qsampler_type_values },
  { "BstQSamplerDrawMode", G_TYPE_ENUM, &bst__type_id__BstQSamplerDrawMode, bst_qsampler_draw_mode_values },

/* --- bstradiotools.h --- */
  { "BstRadioToolsFlags", G_TYPE_FLAGS, &bst__type_id__BstRadioToolsFlags, bst_radio_tools_flags_values },

/* --- bstdefs.h --- */
  { "BstOps", G_TYPE_ENUM, &bst__type_id__BstOps, bst_ops_values },
  { "BstQuantizationType", G_TYPE_ENUM, &bst__type_id__BstQuantizationType, bst_quantization_type_values },

/* Generated data ends here */

